#
# spec file for package python-numpy
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           python-numpy
Version:        1.6.1
Release:        21.1
Url:            http://sourceforge.net/projects/numpy
Summary:        NumPy array processing for numbers, strings, records and objects
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Source:         numpy-%{version}.tar.gz
Patch1:         numpy-buildfix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  lapack
BuildRequires:  blas
%if 0%{?suse_version}
BuildRequires:  gcc-fortran
%py_requires
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif
%else
BuildRequires:  gcc-gfortran
%endif
Provides:       numpy = %{version}
%if ! 0%{?fedora_version}
Provides:       python-numeric = %{version}
Obsoletes:      python-numeric < %{version}
%endif
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%description
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

%package devel
Summary:        Development files for numpy applications
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python-devel
Requires:       lapack
Requires:       blas
%if 0%{?suse_version}
Requires:       gcc-fortran
%else
BuildRequires:  gcc-gfortran
%endif

%description devel
This package contains files for developing applications using numpy.

%prep
%setup -q -n numpy-%{version}
%patch1 -p0
sed -i "1d" numpy/{compat/setup{,scons},distutils/{conv_template,cpuinfo,exec_command,from_template,setup,setupscons,system_info},f2py/{auxfuncs,capi_maps,cb_rules,cfuncs,common_rules,crackfortran,diagnose,docs/usersguide/setup_example,f2py2e,f90mod_rules,func2subr,__init__,rules,setup,setupscons,use_rules},ma/setup{,scons},matrixlib/setup{,scons},setup,setupscons,testing/print_coercion_tables,testing/setup{,scons}}.py # Fix non-executable scripts

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build

%install
python setup.py install --root="%{buildroot}" --prefix="%{_prefix}"
rm -rf %{buildroot}%{python_sitearch}/numpy/{,core,distutils,f2py,fft,ma,matrixlib,oldnumeric,polynomial,random,testing}/tests # Don't package testsuite
%if 0%{?suse_version} > 1020
%fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root)
%doc *.txt
%{_bindir}/*
%{python_sitearch}/*
%exclude %{python_sitearch}/numpy/*/*/*.c
%exclude %{python_sitearch}/numpy/*/*.h
%exclude %{python_sitearch}/numpy/*/*/*.h
%exclude %{python_sitearch}/numpy/*/*/*/*.h
%exclude %{python_sitearch}/numpy/core/lib/libnpymath.a

%files devel
%defattr(-,root,root)
%{python_sitearch}/numpy/*/*/*.c
%{python_sitearch}/numpy/*/*.h
%{python_sitearch}/numpy/*/*/*.h
%{python_sitearch}/numpy/*/*/*/*.h
%{python_sitearch}/numpy/core/lib/libnpymath.a

%changelog
* Sat Oct  1 2011 behrisch@users.sf.net
- Added static lib to devel package for scipy build
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 1.6.1:
  * Please see http://downloads.sourceforge.net/project/numpy/NumPy/1.6.1/Changelog
- Spec file cleanup:
  * Set license to BSD-3-Clause (SPDX style)
  * Removed testsuite from packages
  * Removed rpmlintrc file and actually fixed the issues
* Sun Jan 23 2011 toddrme2178@gmail.com
- update to 1.5.1
  Numpy 1.5.1 is a bug-fix release with no new
  features compared to 1.5.0.
  Relevant bugs fixed:
  * linalg: lstsq should always return real residual
  * lib: fix negative indices in s_ and index_exp
  * core: fix uint64 -> Python int cast
  * core: richcompare should return Py_NotImplemented when undefined
  * lib: close file handles after use in numpy.lib.npyio.*
  * core: ensure PEP 3118 buffers can be released in exception handler
  * core: fix clongdouble cast to Python complex()
  * core: fix detection for ``isfinite`` routine
* Mon Sep  6 2010 coolo@novell.com
- update to 1.5.0 to fix build against python 2.7
  highlights 1.3 -> 1.4:
  * New datetime dtype support to deal with dates in arrays
  * Faster import time
  * Extended array wrapping mechanism for ufuncs
  * New Neighborhood iterator (C-level only)
  * C99-like complex functions in npymath
  highlights 1.4 -> 1.5:
  * support for python3 and python 2.7
* Mon May 31 2010 bg@novell.com
- fix build for hppa
* Fri Jan 15 2010 aeszter@gwdg.de
- re-enable build on non-SUSE distros
- do not provide python-numeric on Fedora, since a package by that
  name exists
* Wed Jan 13 2010 lars@linux-schulserver.de
- use a more generic way to define py_sitedir on all targets
* Mon Jan 11 2010 coolo@novell.com
- remerge d:l:p version with O:F version
  - split -devel package and add support for !suse targets
* Wed Apr  8 2009 matejcik@suse.cz
- update to 1.3.0
  * official python 2.6 support (although it did (mostly)
    work before)
  * new multiarray APIs
* Wed Feb 11 2009 ro@suse.de
- fix filelist by using "--record-rpm" instead of "--record"
  (and do not quote lines starting with "%%dir ")
* Wed Feb  4 2009 matejcik@suse.cz
- package taken directly from devel:languages:python repository,
  original changelog follows:
* Tue Dec  2 2008 James Oakley <jfunk@funktronics.ca> - 1.2.1-1
- Update to 1.2.1
* Mon Aug 11 2008 James Oakley <jfunk@funktronics.ca> - 1.1.1-1
- Update to 1.1.1:
  - Python 2.3.x fixes
  * Robert Kern -- remove development branch of f2py.
  * Pierre GM -- masked array, fix dictionary update.
  * Pierre GM -- masked array, fix itertools groupby dependency.
  * Pierre GM -- masked array, fix use of iterators.
  * Neil Muller -- fix test dependency on pretty print (#828).
  - General improvements
  * David Cournapeau -- scons build fixes/improvements.
  * Stefan van der Walt -- Howto document updates.
  * Fernando Perez -- cython updates.
  * Robert Kern -- PyPI metadata fixes.
  - Bug fixes
  * #791 -- Travis Oliphant, std/var not properly calling array_finalize.
  * #798 -- Stefan van der Walt, piecewise exposes raw memory.
  * #810 -- David Huard, Verbose argument not effective for ndarrays in assert_equal.
  * #828 -- Neil Muller, numpy file format format test failures on Solaris.
  * #825 -- Neil Muller/Charles Harris, SIGBUS in UNICODE_getattr on Sparc Linux.
  * #837 -- Pauli Virtanen, Infinite loop in fromfile & fromstring
  * #841 -- Charles Harris, make numpy complex types print like Python.
  * #843 -- Michael Abbott, reference count error in PyArray_CanCoerceScalar
  * #844 -- David Cournapeau, failure with numpy inner.
  * #848 -- Michael Abbott/Charles Harris/Travis Oliphant, reference leak.
  * #849 -- Michael Abbott, reference to deallocated object.
  * #850 -- Michael Abbott, memory leak.
  * #854 -- Pauli Virtanen, Non-standard branch cuts (arccosh).
  * #857 -- Pierre GM, dividing masked array with newaxis fails.
  * ------- David Cournapeau, ctypes load_library fix.
  * ------- Ryan May, Stefan van der Walt, fix loadtxt.
  * ------- Robert Kern, make numeric.py functions return booleans.
  * ------- Robert Kern, correct old numeric typecodes.
  * ------- Robert Kern, fix raising exception in tests.
  * ------- Robert Kern, make sure Zipf results are in allowable range.
  * ------- Robert Kern, fix c++ style comment.
